"""
Exports VS16_NARROW_TO_WIDE table keyed by supporting unicode version level.

This code generated by wcwidth/bin/update-tables.py on 2023-11-07 16:43:49 UTC.
"""
VS16_NARROW_TO_WIDE = {
    '9.0.0': (
        # Source: 9.0.0
        # Date: 2023-02-01, 02:22:54 GMT
        #
        (0x00023, 0x00023,),  # Number Sign
        (0x0002a, 0x0002a,),  # Asterisk
        (0x00030, 0x00039,),  # Digit Zero              ..Digit Nine
        (0x000a9, 0x000a9,),  # Copyright Sign
        (0x000ae, 0x000ae,),  # Registered Sign
        (0x0203c, 0x0203c,),  # Double Exclamation Mark
        (0x02049, 0x02049,),  # Exclamation Question Mark
        (0x02122, 0x02122,),  # Trade Mark Sign
        (0x02139, 0x02139,),  # Information Source
        (0x02194, 0x02199,),  # Left Right Arrow        ..South West Arrow
        (0x021a9, 0x021aa,),  # Leftwards Arrow With Hoo..Rightwards Arrow With Ho
        (0x02328, 0x02328,),  # Keyboard
        (0x023cf, 0x023cf,),  # Eject Symbol
        (0x023ed, 0x023ef,),  # Black Right-pointing Dou..Black Right-pointing Tri
        (0x023f1, 0x023f2,),  # Stopwatch               ..Timer Clock
        (0x023f8, 0x023fa,),  # Double Vertical Bar     ..Black Circle For Record
        (0x024c2, 0x024c2,),  # Circled Latin Capital Letter M
        (0x025aa, 0x025ab,),  # Black Small Square      ..White Small Square
        (0x025b6, 0x025b6,),  # Black Right-pointing Triangle
        (0x025c0, 0x025c0,),  # Black Left-pointing Triangle
        (0x025fb, 0x025fc,),  # White Medium Square     ..Black Medium Square
        (0x02600, 0x02604,),  # Black Sun With Rays     ..Comet
        (0x0260e, 0x0260e,),  # Black Telephone
        (0x02611, 0x02611,),  # Ballot Box With Check
        (0x02618, 0x02618,),  # Shamrock
        (0x0261d, 0x0261d,),  # White Up Pointing Index
        (0x02620, 0x02620,),  # Skull And Crossbones
        (0x02622, 0x02623,),  # Radioactive Sign        ..Biohazard Sign
        (0x02626, 0x02626,),  # Orthodox Cross
        (0x0262a, 0x0262a,),  # Star And Crescent
        (0x0262e, 0x0262f,),  # Peace Symbol            ..Yin Yang
        (0x02638, 0x0263a,),  # Wheel Of Dharma         ..White Smiling Face
        (0x02640, 0x02640,),  # Female Sign
        (0x02642, 0x02642,),  # Male Sign
        (0x0265f, 0x02660,),  # Black Chess Pawn        ..Black Spade Suit
        (0x02663, 0x02663,),  # Black Club Suit
        (0x02665, 0x02666,),  # Black Heart Suit        ..Black Diamond Suit
        (0x02668, 0x02668,),  # Hot Springs
        (0x0267b, 0x0267b,),  # Black Universal Recycling Symbol
        (0x0267e, 0x0267e,),  # Permanent Paper Sign
        (0x02692, 0x02692,),  # Hammer And Pick
        (0x02694, 0x02697,),  # Crossed Swords          ..Alembic
        (0x02699, 0x02699,),  # Gear
        (0x0269b, 0x0269c,),  # Atom Symbol             ..Fleur-de-lis
        (0x026a0, 0x026a0,),  # Warning Sign
        (0x026a7, 0x026a7,),  # Male With Stroke And Male And Female Sign
        (0x026b0, 0x026b1,),  # Coffin                  ..Funeral Urn
        (0x026c8, 0x026c8,),  # Thunder Cloud And Rain
        (0x026cf, 0x026cf,),  # Pick
        (0x026d1, 0x026d1,),  # Helmet With White Cross
        (0x026d3, 0x026d3,),  # Chains
        (0x026e9, 0x026e9,),  # Shinto Shrine
        (0x026f0, 0x026f1,),  # Mountain                ..Umbrella On Ground
        (0x026f4, 0x026f4,),  # Ferry
        (0x026f7, 0x026f9,),  # Skier                   ..Person With Ball
        (0x02702, 0x02702,),  # Black Scissors
        (0x02708, 0x02709,),  # Airplane                ..Envelope
        (0x0270c, 0x0270d,),  # Victory Hand            ..Writing Hand
        (0x0270f, 0x0270f,),  # Pencil
        (0x02712, 0x02712,),  # Black Nib
        (0x02714, 0x02714,),  # Heavy Check Mark
        (0x02716, 0x02716,),  # Heavy Multiplication X
        (0x0271d, 0x0271d,),  # Latin Cross
        (0x02721, 0x02721,),  # Star Of David
        (0x02733, 0x02734,),  # Eight Spoked Asterisk   ..Eight Pointed Black Star
        (0x02744, 0x02744,),  # Snowflake
        (0x02747, 0x02747,),  # Sparkle
        (0x02763, 0x02764,),  # Heavy Heart Exclamation ..Heavy Black Heart
        (0x027a1, 0x027a1,),  # Black Rightwards Arrow
        (0x02934, 0x02935,),  # Arrow Pointing Rightward..Arrow Pointing Rightward
        (0x02b05, 0x02b07,),  # Leftwards Black Arrow   ..Downwards Black Arrow
        (0x1f170, 0x1f171,),  # Negative Squared Latin C..Negative Squared Latin C
        (0x1f17e, 0x1f17f,),  # Negative Squared Latin C..Negative Squared Latin C
        (0x1f321, 0x1f321,),  # Thermometer
        (0x1f324, 0x1f32c,),  # White Sun With Small Clo..Wind Blowing Face
        (0x1f336, 0x1f336,),  # Hot Pepper
        (0x1f37d, 0x1f37d,),  # Fork And Knife With Plate
        (0x1f396, 0x1f397,),  # Military Medal          ..Reminder Ribbon
        (0x1f399, 0x1f39b,),  # Studio Microphone       ..Control Knobs
        (0x1f39e, 0x1f39f,),  # Film Frames             ..Admission Tickets
        (0x1f3cb, 0x1f3ce,),  # Weight Lifter           ..Racing Car
        (0x1f3d4, 0x1f3df,),  # Snow Capped Mountain    ..Stadium
        (0x1f3f3, 0x1f3f3,),  # Waving White Flag
        (0x1f3f5, 0x1f3f5,),  # Rosette
        (0x1f3f7, 0x1f3f7,),  # Label
        (0x1f43f, 0x1f43f,),  # Chipmunk
        (0x1f441, 0x1f441,),  # Eye
        (0x1f4fd, 0x1f4fd,),  # Film Projector
        (0x1f549, 0x1f54a,),  # Om Symbol               ..Dove Of Peace
        (0x1f56f, 0x1f570,),  # Candle                  ..Mantelpiece Clock
        (0x1f573, 0x1f579,),  # Hole                    ..Joystick
        (0x1f587, 0x1f587,),  # Linked Paperclips
        (0x1f58a, 0x1f58d,),  # Lower Left Ballpoint Pen..Lower Left Crayon
        (0x1f590, 0x1f590,),  # Raised Hand With Fingers Splayed
        (0x1f5a5, 0x1f5a5,),  # Desktop Computer
        (0x1f5a8, 0x1f5a8,),  # Printer
        (0x1f5b1, 0x1f5b2,),  # Three Button Mouse      ..Trackball
        (0x1f5bc, 0x1f5bc,),  # Frame With Picture
        (0x1f5c2, 0x1f5c4,),  # Card Index Dividers     ..File Cabinet
        (0x1f5d1, 0x1f5d3,),  # Wastebasket             ..Spiral Calendar Pad
        (0x1f5dc, 0x1f5de,),  # Compression             ..Rolled-up Newspaper
        (0x1f5e1, 0x1f5e1,),  # Dagger Knife
        (0x1f5e3, 0x1f5e3,),  # Speaking Head In Silhouette
        (0x1f5e8, 0x1f5e8,),  # Left Speech Bubble
        (0x1f5ef, 0x1f5ef,),  # Right Anger Bubble
        (0x1f5f3, 0x1f5f3,),  # Ballot Box With Ballot
        (0x1f5fa, 0x1f5fa,),  # World Map
        (0x1f6cb, 0x1f6cb,),  # Couch And Lamp
        (0x1f6cd, 0x1f6cf,),  # Shopping Bags           ..Bed
        (0x1f6e0, 0x1f6e5,),  # Hammer And Wrench       ..Motor Boat
        (0x1f6e9, 0x1f6e9,),  # Small Airplane
        (0x1f6f0, 0x1f6f0,),  # Satellite
        (0x1f6f3, 0x1f6f3,),  # Passenger Ship
    ),
}
